pub struct RawAdvanceWidthBatch {
pub len: usize,
pub gids: *const u32,
pub advances: *mut i32,
pub gid_stride: isize,
pub advance_stride: isize,
}Expand description
Raw C-style view over a batch of glyph ids and advance widths.
Fields
len: usizeNumber of batch entries.
gids: *const u32Pointer to glyph ids (read-only).
advances: *mut i32Pointer to horizontal advances (writable).
See “Metrics scaling” in the FontFuncs for details on what value this method should return.
gid_stride: isizeByte stride between successive glyph ids.
advance_stride: isizeByte stride between successive advances.